==> youtrack_rest_client-0.1.1-py3-none-any.whl: youtrack_rest_client/api/default/post_admin_custom_field_settings_bundles_owned_field_id.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.owned_bundle import OwnedBundle
from ...types import UNSET, Response, Unset


def _get_kwargs(
    id: str,
    *,
    client: Client,
    json_body: OwnedBundle,
    fields: Union[Unset, None, str] = "$type,id",
) -> Dict[str, Any]:
    url = "{}/admin/customFieldSettings/bundles/ownedField/{id}".format(client.youtrack_base_url, id=id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "fields": fields,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[OwnedBundle]:
    if response.status_code == 200:
        response_200 = OwnedBundle.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[OwnedBundle]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    id: str,
    *,
    client: Client,
    json_body: OwnedBundle,
    fields: Union[Unset, None, str] = "$type,id",
) -> Response[OwnedBundle]:
    kwargs = _get_kwargs(
        id=id,
        client=client,
        json_body=json_body,
        fields=fields,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    id: str,
    *,
    client: Client,
    json_body: OwnedBundle,
    fields: Union[Unset, None, str] = "$type,id",
) -> Optional[OwnedBundle]:
    """ """

    return sync_detailed(
        id=id,
        client=client,
        json_body=json_body,
        fields=fields,
    ).parsed


async def asyncio_detailed(
    id: str,
    *,
    client: Client,
    json_body: OwnedBundle,
    fields: Union[Unset, None, str] = "$type,id",
) -> Response[OwnedBundle]:
    kwargs = _get_kwargs(
        id=id,
        client=client,
        json_body=json_body,
        fields=fields,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    id: str,
    *,
    client: Client,
    json_body: OwnedBundle,
    fields: Union[Unset, None, str] = "$type,id",
) -> Optional[OwnedBundle]:
    """ """

    return (
        await asyncio_detailed(
            id=id,
            client=client,
            json_body=json_body,
            fields=fields,
        )
    ).parsed

==> youtrack_rest_client-0.1.2-py3-none-any.whl: youtrack_rest_client/api/default/post_admin_custom_field_settings_bundles_owned_field_id.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models import owned_bundle as owned_bundle_m
from ...types import UNSET, Response, Unset


def _get_kwargs(
    id: "str",
    *,
    client: Client,
    json_body: owned_bundle_m.OwnedBundle,
    fields: "Union[Unset, None, str]" = "$type,id",
) -> Dict[str, Any]:
    url = "{}/admin/customFieldSettings/bundles/ownedField/{id}".format(client.youtrack_base_url, id=id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "fields": fields,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[owned_bundle_m.OwnedBundle]:
    if response.status_code == 200:
        response_200 = owned_bundle_m.OwnedBundle.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[owned_bundle_m.OwnedBundle]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    id: "str",
    *,
    client: Client,
    json_body: owned_bundle_m.OwnedBundle,
    fields: "Union[Unset, None, str]" = "$type,id",
) -> Response[owned_bundle_m.OwnedBundle]:
    kwargs = _get_kwargs(
        id=id,
        client=client,
        json_body=json_body,
        fields=fields,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    id: "str",
    *,
    client: Client,
    json_body: owned_bundle_m.OwnedBundle,
    fields: "Union[Unset, None, str]" = "$type,id",
) -> Optional[owned_bundle_m.OwnedBundle]:
    """ """

    return sync_detailed(
        id=id,
        client=client,
        json_body=json_body,
        fields=fields,
    ).parsed


async def asyncio_detailed(
    id: "str",
    *,
    client: Client,
    json_body: owned_bundle_m.OwnedBundle,
    fields: "Union[Unset, None, str]" = "$type,id",
) -> Response[owned_bundle_m.OwnedBundle]:
    kwargs = _get_kwargs(
        id=id,
        client=client,
        json_body=json_body,
        fields=fields,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    id: "str",
    *,
    client: Client,
    json_body: owned_bundle_m.OwnedBundle,
    fields: "Union[Unset, None, str]" = "$type,id",
) -> Optional[owned_bundle_m.OwnedBundle]:
    """ """

    return (
        await asyncio_detailed(
            id=id,
            client=client,
            json_body=json_body,
            fields=fields,
        )
    ).parsed
